@@ -379,7 +379,7 @@ clustTrend <-
 				}
 			}
 			
-			if(sum(apply(data_stand_ByTP, MARGIN=2, FUN=var))<1.e-25){
+			if(sum(apply(data_stand_ByTP, MARGIN=2, FUN=var), na.rm = TRUE)<1.e-25){
 				nc <- 1
 				clust <- rep(1, dim(data_stand)[1])
 			} 
@@ -387,12 +387,12 @@ clustTrend <-
 				kmax <- ifelse(dim(data_stand_ByTP)[1]>4, max_trends, dim(data_stand_ByTP)[1]-1)
 				if(kmax>=2){
 					if(clustering_metric!="sts"){
-						cG <- clusGap(x=data_stand_ByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE)
-						nc <- maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
+						cG <- cluster::clusGap(x=data_stand_ByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE)
+						nc <- cluster::maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
 						clust <- FUNcluster(data_stand_ByTP, k=nc)$cluster
 					}else{
-						cG <- clusGap(x=data_stand_ByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE, time=as.numeric(colnames(data_stand_ByTP)))
-						nc <- maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
+						cG <- cluster::clusGap(x=data_stand_ByTP, FUNcluster=FUNcluster, K.max=kmax, B=B, verbose=FALSE, time=as.numeric(colnames(data_stand_ByTP)))
+						nc <- cluster::maxSE(f = cG$Tab[, "gap"], SE.f = cG$Tab[, "SE.sim"], method = methodOptiClust)
 						clust <- FUNcluster(data_stand_ByTP, k=nc, time=as.numeric(colnames(data_stand_ByTP)))$cluster
 					}
 				}else{
@@ -400,7 +400,6 @@ clustTrend <-
 					clust <- rep(1, dim(data_stand)[1])
 				}
 			}
-			
 			medoids <- as.data.frame(t(apply(X=data_stand_ByTP, MARGIN=2, FUN=Fun_byIndex, index=clust, fun=trend.fun)))
 			if(dim(medoids)[1]==1){
 				medoids <- cbind.data.frame("TimePoint"= colnames(medoids), "1"=t(medoids))
